@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "0.9803";
+our $VERSION = "0.9804";
 
 =head1 NAME
 
@@ -88,6 +88,52 @@ If you pass parameters to import, a default service will be set
 meaning method calls will not require the webservice url. Unless you are
 intending to access multiple services, this form is recommended.
 
+=head2 Using Queries
+
+The main reason to access the InterMine webservices is to query for data. 
+The most flexible way to do this is by using Queries:
+
+    my $query = $service->new_query(class => "Gene");
+    $query->select("*", "proteins.*")->where(symbol => [qw/h r eve zen bib/]);
+
+    while (my $gene = <$query>) {
+        print $gene->symbol, map {$_->name} $gene->proteins, "\n";
+    }
+
+As you can see, queries can be concisely defined, and their results easily 
+accessed. You can process a query's results all at once, or using iteration, as in
+the example above. Iteration is less memory hungry, as only the current row of 
+data needs to be held in memory at once, which can be important when dealing
+with large data sets.
+
+=head2 Using Templates
+
+Templates are predefined queries that make running queries easier, as you don't
+have to define the logic yourself. Every mine comes with many predefined
+searches, and you just have to enter a few parameters:
+
+    my $results = $service->template("Gene_Proteins")->results_with(valueA => "eve");
+
+These templates are simple to use, and they have all the power of full queries 
+as well. You can process results just as powerfully with them.
+
+=head2 Using Lists
+
+Lists are saved result sets in a webservice you can access, create, modify and delete
+(provided you are logged in):
+
+    my $service = Webservice::InterMine->get_service("flymine", "MYTOKEN");
+    my $list = $service->list("MyAwesomeList");
+    my $new_list = $service->new_list(content => "some_file.text", type => "Gene");
+    my $intersection = $list & $new_list;
+    $intersection->rename("GenesInCommon");
+    $new_list->delete; # Not actually necessary - it had no name so would have been automatically deleted anyway.
+
+Lists enable you to collect and manage results and lists of items of interest to you.
+You can use them in queries, and display their contents, as well as perforing
+set-logic operations on them. When you are done, you can view the lists in the webservice, 
+where you can use the analysis widgets to assess the data you have processed.
+
 =head1 METHODS
 
 =cut
